@@ -496,7 +496,6 @@ postStr_wt <- function(svysmpl, svypopu, auxVars, svyVar, subset = NULL, family
 #'              Default is 1000.
 #' @param nchain An integer specifying the number of MCMC chains for Stan models. Default is 4.
 #' @param printmod A logical scalar; if `TRUE`, posterior estimates will be printed.
-#' @param doFigure A logical scalar; if `TRUE`, MCMC diagnostic plots will be generated.
 #' @param useTrueSample A logical scalar; if `TRUE`, the estimator will use true sample information.
 #' @param stan_verbose A logical scalar; if `TRUE`, MCMC information will be printed during Stan model fitting.
 #' @param HPD_CI A logical scalar; if `TRUE`, the calculated credible intervals will be highest posterior density intervals (HPD).
@@ -510,7 +509,6 @@ postStr_wt <- function(svysmpl, svypopu, auxVars, svyVar, subset = NULL, family
 #'         - Other elements based on the specified confidence levels in `invlvls`.
 #'
 #' @examples
-#' \donttest{
 #' ## Example usage with survey data:
 #' ## Simulate sample and population data
 #' data = simulate(N = 3000, discretize = 3, setting = 3, seed = 123)
@@ -526,9 +524,8 @@ postStr_wt <- function(svysmpl, svypopu, auxVars, svyVar, subset = NULL, family
 #' bayes_model = svyBayesmod(svysmpl = samples, svypopu = population,
 #'                           outcome_formula = outcome_formula,
 #'                           BayesFun = BayesFun, weights = ipw,
-#'                           family = gaussian(), nskip = 2000, npost = 2000,
+#'                           family = gaussian(), nskip = 20, npost = 20,
 #'                           nchain = 2, printmod = TRUE, invlvls = 0.95, stan_verbose = TRUE)
-#' }
 #'
 #' @rawNamespace import(stats, except = filter)
 #' @import rstanarm
@@ -539,7 +536,7 @@ postStr_wt <- function(svysmpl, svypopu, auxVars, svyVar, subset = NULL, family
 #'
 #' @export
 
-svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NULL, family = gaussian(), invlvls, weights = NULL, nskip = 1000, npost = 1000, nchain = 4, printmod = TRUE, doFigure = FALSE, useTrueSample = FALSE, stan_verbose = FALSE, HPD_CI = FALSE, seed = NULL) {
+svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NULL, family = gaussian(), invlvls, weights = NULL, nskip = 1000, npost = 1000, nchain = 4, printmod = TRUE, useTrueSample = FALSE, stan_verbose = FALSE, HPD_CI = FALSE, seed = NULL) {
   if (!is.null(seed))
     set.seed(seed)
   #print(outcome_formula)
@@ -586,20 +583,12 @@ svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NU
   #bayesmod <- update(bayesmod, iter = 500)
 
   if (printmod) summary(bayesmod) %>% print()
-
-  if (doFigure) {
-    p1 <- pp_check(bayesmod)
-    p2 <- pp_check(bayesmod, plotfun = 'scatter_avg')
-    p3 <- pp_check(bayesmod, plotfun = 'stat_2d', stat = c('mean', 'sd'))
-    p4 <- pp_check(bayesmod, plotfun = "error_binned")
-    ppcFig <- gridExtra::grid.arrange(p1, p2, p3, ncol = 3)
-    ppcFig <- gridExtra::grid.arrange(ppcFig, p4, ncol = 1)
-    ppcFig
-  }
   if(useTrueSample == FALSE){
     infr = sapply(subset, function(s){
-      #print(s)
       svypopu1 = dplyr::filter(svypopu, eval(parse(text = s)))
+
+
+
       yhats <- posterior_epred(bayesmod, svypopu1)
 
       post_est = rowMeans(yhats)
@@ -705,8 +694,6 @@ svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NU
 #' Multiple values can be specified to calculate multiple CIs.
 #' @param stan_verbose A logical scalar; if `TRUE`, prints all messages when running Stan models. Default is `FALSE`.
 #' This parameter only applies to Bayesian models.
-#' @param show_plot A logical scalar; if `TRUE`, shows diagnostic plots for Stan models. Default is `FALSE`.
-#' This parameter only applies to Bayesian models.
 #' @param nskip An integer specifying the number of burn-in iterations for each chain in MCMC for Stan models.
 #' Default is `1000`. This parameter only applies to Bayesian models.
 #' @param npost An integer specifying the number of posterior sampling iterations for each chain in MCMC for Stan models.
@@ -725,7 +712,6 @@ svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NU
 #'         - Other elements for each confidence level specified in `levels`.
 #'
 #' @examples
-#' \donttest{
 #' ## Simulate data with nonlinear association (setting 3).
 #' data = simulate(N = 3000, discretize = 10, setting = 3, seed = 123)
 #' population = data$population
@@ -747,21 +733,20 @@ svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NU
 #' ## MRP
 #' MRP = auxsurvey("Y1 ~ 1 + Z1", auxiliary = "Z2 + Z3:auX_10", samples = samples,
 #'                 population = population, subset = c("Z1 == 1", "Z1 == 1 & Z2 == 1"),
-#'                 method = "MRP", levels = 0.95, nskip = 4000, npost = 4000,
-#'                 nchain = 1, stan_verbose = FALSE, HPD_interval = TRUE)
+#'                 method = "MRP", levels = 0.95, nskip = 40, npost = 40,
+#'                 nchain = 1, stan_verbose = FALSE, HPD_interval = TRUE, seed = 123)
 #'
 #' ## GAMP
 #' GAMP = auxsurvey("Y1 ~ 1 + Z1 + Z2 + Z3", auxiliary = "s(auX_10) + s(logit_true_pi, by = Z1)",
 #'                  samples = samples, population = population, method = "GAMP",
-#'                  levels = 0.95, nskip = 4000, npost = 4000, nchain = 1,
-#'                  stan_verbose = FALSE, HPD_interval = TRUE)
+#'                  levels = 0.95, nskip = 40, npost = 40, nchain = 1,
+#'                  stan_verbose = FALSE, HPD_interval = TRUE, seed = 123)
 #'
 #' ## BART
 #' BART = auxsurvey("Y1 ~ Z1 + Z2 + Z3 + auX_10", auxiliary = NULL, samples = samples,
 #'                  population = population, method = "BART", levels = 0.95,
-#'                  nskip = 4000, npost = 4000, nchain = 1, HPD_interval = TRUE)
+#'                  nskip = 40, npost = 40, nchain = 1, HPD_interval = TRUE, seed = 123)
 #'
-#' }
 #'
 #' @rawNamespace import(stats, except = filter)
 #' @import rstanarm
@@ -772,7 +757,7 @@ svyBayesmod <- function(svysmpl, svypopu, outcome_formula, BayesFun, subset = NU
 #' @import BART
 #'
 #' @export
-auxsurvey <- function(formula, auxiliary = NULL, samples, population = NULL, subset = NULL, family = gaussian(), method = c("sample_mean", "rake", "postStratify", "MRP", "GAMP", "linear", "BART"), weights = NULL, levels = c(0.95, 0.8, 0.5), stan_verbose = TRUE, show_plot = TRUE, nskip = 1000, npost = 1000, nchain = 4, HPD_interval = FALSE, seed = NULL){
+auxsurvey <- function(formula, auxiliary = NULL, samples, population = NULL, subset = NULL, family = gaussian(), method = c("sample_mean", "rake", "postStratify", "MRP", "GAMP", "linear", "BART"), weights = NULL, levels = c(0.95, 0.8, 0.5), stan_verbose = TRUE, nskip = 1000, npost = 1000, nchain = 4, HPD_interval = FALSE, seed = NULL){
   if(!is.null(seed))
     set.seed(seed)
 
@@ -845,7 +830,7 @@ auxsurvey <- function(formula, auxiliary = NULL, samples, population = NULL, sub
       outcome_formula = paste(paste0(svyVar, "~", paste0(covariates, collapse = "+")), paste0("(1|", auxiliary, ")", collapse = "+"), sep= "+")
     }
     message("The formula for the MRP model is ", outcome_formula, "\n")
-    MRP_est = svyBayesmod(samples, population, outcome_formula, "stan_glmer", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, doFigure = show_plot, useTrueSample = FALSE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
+    MRP_est = svyBayesmod(samples, population, outcome_formula, "stan_glmer", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, useTrueSample = FALSE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
     #return(MRP_est)
     MRP_est =  lapply(MRP_est, function(est){
       if(is.null(weights))
@@ -894,7 +879,7 @@ auxsurvey <- function(formula, auxiliary = NULL, samples, population = NULL, sub
 
     #outcome_formula = paste(formula, paste0(str_remove_all(auxiliary, "~"), collapse = "+"), paste0("(1|", auxiliary_random, ")", collapse = "+"),  sep = "+")
 
-    GAMP_est = svyBayesmod(samples, population, outcome_formula, "stan_gamm4", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, doFigure = FALSE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval, seed = seed)
+    GAMP_est = svyBayesmod(samples, population, outcome_formula, "stan_gamm4", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval, seed = seed)
     #print(GAMP_est)
 
     GAMP_est =  lapply(GAMP_est, function(est){
@@ -927,11 +912,11 @@ auxsurvey <- function(formula, auxiliary = NULL, samples, population = NULL, sub
     if(length(auxiliary_random) != 0){
       outcome_formula = c(outcome_formula, paste0("~", paste0("(1|", auxiliary_random, ")", collapse = "+")))
       message("The formula for the linear model is ", paste0(outcome_formula[1], str_replace(outcome_formula[2], "~", "+"), collapse = ""), "\n")
-      Linear_est = svyBayesmod(samples, population, outcome_formula, "stan_glmer", family, levels, weights, nskip, npost, nchain, printmod = TRUE, doFigure = FALSE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
+      Linear_est = svyBayesmod(samples, population, outcome_formula, "stan_glmer", family, levels, weights, nskip, npost, nchain, printmod = TRUE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
     }else{
       outcome_formula = c(outcome_formula, NULL)
       message("The formula for the linear model is ", outcome_formula, "\n")
-      Linear_est = svyBayesmod(samples, population, outcome_formula, "stan_glm", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, doFigure = FALSE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
+      Linear_est = svyBayesmod(samples, population, outcome_formula, "stan_glm", subset, family, levels, weights, nskip, npost, nchain, printmod = TRUE, useTrueSample = TRUE, stan_verbose = stan_verbose, HPD_CI = HPD_interval)
     }
 
 
